@@ -555,6 +555,7 @@ class BertGuideHead(nn.Module):
         guide=None,
         extraction='softmax', softmax_threshold=0.001,
         train_so=True, train_co=False,
+        output_prob=False,
     ):
         #mask
         attention_mask_src = ( (inputs_src==PAD_ID) + (inputs_src==CLS_ID) + (inputs_src==SEP_ID) ).float()
@@ -582,7 +583,14 @@ class BertGuideHead(nn.Module):
 
         if guide is None:
             threshold = softmax_threshold if extraction == 'softmax' else 0
-            return (attention_probs_src>threshold)*(attention_probs_tgt>threshold)
+            align_matrix = (attention_probs_src>threshold)*(attention_probs_tgt>threshold)
+            if not output_prob:
+                return align_matrix
+            # A heuristic of generating the alignment probability
+            attention_probs_src = nn.Softmax(dim=-1)(attention_scores_src/torch.sqrt(len_tgt.view(-1, 1, 1, 1)))
+            attention_probs_tgt = nn.Softmax(dim=-2)(attention_scores_tgt/torch.sqrt(len_src.view(-1, 1, 1, 1)))
+            align_prob = (2*attention_probs_src*attention_probs_tgt)/(attention_probs_src+attention_probs_tgt+1e-9) 
+            return align_matrix, align_prob
 
         so_loss = 0
         if train_so:
@@ -667,7 +675,7 @@ class BertForMaskedLM(BertPreTrainedModel):
         sco_loss = self.guide_layer(outputs_src, outputs_tgt, inputs_src, inputs_tgt, guide=guide, extraction=extraction, softmax_threshold=softmax_threshold, train_so=train_so, train_co=train_co)
         return sco_loss
 
-    def get_aligned_word(self, inputs_src, inputs_tgt, bpe2word_map_src, bpe2word_map_tgt, device, src_len, tgt_len, align_layer=8, extraction='softmax', softmax_threshold=0.001, test=False):
+    def get_aligned_word(self, inputs_src, inputs_tgt, bpe2word_map_src, bpe2word_map_tgt, device, src_len, tgt_len, align_layer=8, extraction='softmax', softmax_threshold=0.001, test=False, output_prob=False):
         inputs_src = inputs_src.to(dtype=torch.long, device=device).clone()
         inputs_tgt = inputs_tgt.to(dtype=torch.long, device=device).clone()
 
@@ -683,7 +691,10 @@ class BertForMaskedLM(BertPreTrainedModel):
                 attention_mask=(inputs_tgt!=PAD_ID),
             )
 
-            attention_probs_inter = self.guide_layer(outputs_src, outputs_tgt, inputs_src, inputs_tgt, extraction=extraction, softmax_threshold=softmax_threshold)
+            attention_probs_inter = self.guide_layer(outputs_src, outputs_tgt, inputs_src, inputs_tgt, extraction=extraction, softmax_threshold=softmax_threshold, output_prob=output_prob)
+            if output_prob:
+                attention_probs_inter, alignment_probs = attention_probs_inter
+                alignment_probs = alignment_probs[:, 0, 1:-1, 1:-1]
             attention_probs_inter = attention_probs_inter.float()
             
         word_aligns = []
@@ -691,10 +702,18 @@ class BertForMaskedLM(BertPreTrainedModel):
         batch_size, bpelen_src, bpelen_tgt = attention_probs_inter.size() 
 
         for idx, (attention, b2w_src, b2w_tgt) in enumerate(zip(attention_probs_inter, bpe2word_map_src, bpe2word_map_tgt)):
-            aligns = set()
+            aligns = set() if not output_prob else dict()
             non_zeros = torch.nonzero(attention)
             for i, j in non_zeros:
-                aligns.add( (b2w_src[i], b2w_tgt[j]) )
+                word_pair = (b2w_src[i], b2w_tgt[j])
+                if output_prob:
+                    prob = alignment_probs[idx, i, j] 
+                    if not word_pair in aligns:
+                        aligns[word_pair] = prob
+                    else:
+                        aligns[word_pair] = max(aligns[word_pair], prob)
+                else:
+                    aligns.add(word_pair)
             word_aligns.append(aligns)
 
         if test:
